@@ -683,7 +683,6 @@ class WebOsClient:
                     timeout=self.timeout_connect,
                 )
 
-                #chros self.handler_tasks.add(asyncio.create_task(inputws.wait_closed()))
                 if self.ping_interval is not None:
                     self.handler_tasks.add(
                         asyncio.create_task(
@@ -828,13 +827,23 @@ class WebOsClient:
         """Play media."""
         return await self.request(ep.POWER_ON)
 
+    async def turn_screen_off_wo4(self):
+        """Turn TV Screen off for WebOS v4.x.
+        standbyMode values: 'active' or 'passive', passive cannot turn screen back on, need to pull TV plug.
+        """
+        return await self.request(ep.TURN_OFF_SCREEN_WO4, {"standbyMode": "active"})
+
+    async def turn_screen_on_wo4(self):
+        """Turn TV Screen on for WebOS v4.x."""
+        return await self.request(ep.TURN_ON_SCREEN_WO4, {"standbyMode": "active"})
+
     async def turn_screen_off(self):
         """Turn TV Screen off."""
-        await self.command("request", ep.TURN_OFF_SCREEN)
+        return await self.request(ep.TURN_OFF_SCREEN, {"standbyMode": "active"})
 
     async def turn_screen_on(self):
         """Turn TV Screen on."""
-        await self.command("request", ep.TURN_ON_SCREEN)
+        return await self.request(ep.TURN_ON_SCREEN, {"standbyMode": "active"})
 
     # 3D Mode
     async def turn_3d_on(self):
